## 0.2.0
added CustomMinimizationReporter

## 0.1.0
- ValidComplex class
    - Handles protein-ligand complex in .cif format
    - Protein only in .cif format
- emulating Schrodinger Desmond default protocol with OpenMM
    - Brownian dynamics after energy minimization
    - NPT at 10 K
